:mod:`exception` -- Exceptions
==============================

.. automodule:: os_brick.exception
   :synopsis: Exceptions generated by os-brick

   .. autoclass:: os_brick.exception.BrickException
   .. autoclass:: os_brick.exception.NotFound
   .. autoclass:: os_brick.exception.Invalid
   .. autoclass:: os_brick.exception.InvalidParameterValue
   .. autoclass:: os_brick.exception.NoFibreChannelHostsFound
   .. autoclass:: os_brick.exception.NoFibreChannelVolumeDeviceFound
   .. autoclass:: os_brick.exception.VolumeDeviceNotFound
   .. autoclass:: os_brick.exception.ProtocolNotSupported
